summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2020-11-19 11:18:24 +0100
committerSebastian Huber <sebastian.huber@embedded-brains.de>2020-11-19 11:18:24 +0100
commite0079d0ea8edd1ba4796999c39f691d9d2d264dd (patch)
tree06bfc5afc2bed464e614c3bee830e5e9881469c1
parentspec: Add partition manager performance items (diff)
downloadrtems-central-e0079d0ea8edd1ba4796999c39f691d9d2d264dd.tar.bz2
specdoc: Fix typo
-rw-r--r--rtemsspec/specdoc.py2
-rw-r--r--rtemsspec/tests/test_specdoc.py6
2 files changed, 4 insertions, 4 deletions
diff --git a/rtemsspec/specdoc.py b/rtemsspec/specdoc.py
index b2dab6e7..9d6d4f63 100644
--- a/rtemsspec/specdoc.py
+++ b/rtemsspec/specdoc.py
@@ -417,7 +417,7 @@ class _Documenter:
def _add_description(self, content: SphinxContent) -> None:
refines = [
- f"{documenter.get_section_reference()} though the "
+ f"{documenter.get_section_reference()} through the "
f"``{key}`` attribute if the value is ``{value}``"
for documenter, key, value in self.refines()
]
diff --git a/rtemsspec/tests/test_specdoc.py b/rtemsspec/tests/test_specdoc.py
index 393ed8e3..192c7146 100644
--- a/rtemsspec/tests/test_specdoc.py
+++ b/rtemsspec/tests/test_specdoc.py
@@ -221,7 +221,7 @@ This type is used by the following types:
A
^
-This type refines the :ref:`SpecTypeRoot` though the ``type`` attribute if the
+This type refines the :ref:`SpecTypeRoot` through the ``type`` attribute if the
value is ``spec``. A description.
The explicit attributes for this type are:
@@ -246,9 +246,9 @@ B
This type refines the following types:
* :ref:`SpecTypeD` though the ``d1`` attribute if the value is ``b``
* :ref:`SpecTypeRoot` though the ``type`` attribute if the value is ``b``
Generic attributes may be specified. Each generic attribute key shall be a
:ref:`SpecTypeName`. Each generic attribute value shall be a list. Each list
@@ -246,9 +246,9 @@ B
This type refines the following types:
-* :ref:`SpecTypeD` though the ``d1`` attribute if the value is ``b``
+* :ref:`SpecTypeD` through the ``d1`` attribute if the value is ``b``
-* :ref:`SpecTypeRoot` though the ``type`` attribute if the value is ``b``
+* :ref:`SpecTypeRoot` through the ``type`` attribute if the value is ``b``
Generic attributes may be specified. Each generic attribute key shall be a
:ref:`SpecTypeName`. Each generic attribute value shall be a list. Each list